/*
 * replacement for malloc and critmalloc
 * written by Arnt Gulbrandsen (c) 1995
 *
 * see README for restrictions on the use of this software
 */

#include "leafnode.h"
#include <stdlib.h>
#include <stdio.h>
#include <syslog.h>

/*
 * replacement for malloc, syslogs allocation failures
 * and exits with the error message
 */
char * critmalloc(size_t size, const char* message) {
    char * a;

    a = (char *)malloc(size);
    if (!a) {
	syslog(LOG_ERR, "malloc(%ld) failed: %s", (long)size, message);
	fprintf(stderr, "malloc(%ld) failed: %s\n", (long)size, message);
	exit(EXIT_FAILURE);
    }
    return a;
}

/*
 * replacement for realloc, syslogs allocation failures
 * and exits with the error message
 */
char * critrealloc(char *a, size_t size, const char* message) {
    a = (char *)realloc(a, size);
    if (!a) {
	syslog(LOG_ERR, "realloc(%ld) failed: %s", (long)size, message);
	fprintf(stderr, "realloc(%ld) failed: %s\n", (long)size, message);
	exit(EXIT_FAILURE);
    }
    return a;
}
